@@ -4,16 +4,16 @@ getGoogleMapsAddress <-  function(street = "Banacha 2", city = "Warszawa", count
     Sys.sleep(delay)
     getGoogleMapsSignleAddress(apiHttp, positionOnly)
   })
-  if (class(res) == "matrix") res <- t(res)
+  if (inherits(res, "matrix")) res <- t(res)
   res
 }
-  
+
 getGoogleMapsSignleAddress <-
 	function(apiHttp, positionOnly = TRUE) {
     level <- 0
     apiHttp <- gsub(apiHttp, pattern=" ", replacement="\\+")
     jsnip <-rjson::fromJSON( file=apiHttp, method = "C" )
-    
+
     if (length(jsnip[[1]]) == 0) {
       apiHttp <- gsub(apiHttp, pattern="[0-9]", replacement="")
       jsnip <- rjson::fromJSON( file=apiHttp, method = "C" )
@@ -26,10 +26,10 @@ getGoogleMapsSignleAddress <-
           apiHttp <- gsub(apiHttp, pattern="address=[^,]*,", replacement="address=")
           jsnip <- rjson::fromJSON( file=apiHttp, method = "C" )
           level <- 3
-        } 
-      } 
-    } 
-  	if (length(jsnip) == 2 & jsnip$status == "OVER_QUERY_LIMIT") 
+        }
+      }
+    }
+  	if (length(jsnip) == 2 & jsnip$status == "OVER_QUERY_LIMIT")
         return("OVER_QUERY_LIMIT")
     if (positionOnly)
        return(c(unlist(jsnip[[1]][[1]]$geometry$location),level))
