@@ -4,7 +4,7 @@ addWeatherVariables <- function(df) {
   if ("apparentTemperature" %in% colnames(df))
     df$apparentTemperatureCelsius <- 5*(df$apparentTemperature-32)/9
   if ("time" %in% colnames(df))
-    df$time <-  as.POSIXct(df$time, origin = "1970-01-01", tz = df$timezone)  
+    df$time <-  as.POSIXct(df$time, origin = "1970-01-01", tz = df$timezone)
   df
 }
 addWeatherDailyVariables <- function(df) {
@@ -17,19 +17,19 @@ addWeatherDailyVariables <- function(df) {
   if ("apparentTemperatureMin" %in% colnames(df))
     df$apparentTemperatureMinCelsius <- 5*(df$apparentTemperatureMin-32)/9
   if ("temperatureMinTime" %in% colnames(df))
-    df$temperatureMinTime <-  as.POSIXct(df$temperatureMinTime, origin = "1970-01-01", tz = df$timezone)  
+    df$temperatureMinTime <-  as.POSIXct(df$temperatureMinTime, origin = "1970-01-01", tz = df$timezone)
   if ("temperatureMaxTime" %in% colnames(df))
-    df$temperatureMaxTime <-  as.POSIXct(df$temperatureMaxTime, origin = "1970-01-01", tz = df$timezone)  
+    df$temperatureMaxTime <-  as.POSIXct(df$temperatureMaxTime, origin = "1970-01-01", tz = df$timezone)
   if ("apparentTemperatureMin" %in% colnames(df))
-    df$apparentTemperatureMin <-  as.POSIXct(df$apparentTemperatureMin, origin = "1970-01-01", tz = df$timezone)  
+    df$apparentTemperatureMin <-  as.POSIXct(df$apparentTemperatureMin, origin = "1970-01-01", tz = df$timezone)
   if ("apparentTemperatureMax" %in% colnames(df))
-    df$apparentTemperatureMax <-  as.POSIXct(df$apparentTemperatureMax, origin = "1970-01-01", tz = df$timezone)  
+    df$apparentTemperatureMax <-  as.POSIXct(df$apparentTemperatureMax, origin = "1970-01-01", tz = df$timezone)
   if ("sunriseTime" %in% colnames(df))
-    df$sunriseTime <-  as.POSIXct(df$sunriseTime, origin = "1970-01-01", tz = df$timezone)  
+    df$sunriseTime <-  as.POSIXct(df$sunriseTime, origin = "1970-01-01", tz = df$timezone)
   if ("sunsetTime" %in% colnames(df))
-    df$sunsetTime <-  as.POSIXct(df$sunsetTime, origin = "1970-01-01", tz = df$timezone)  
+    df$sunsetTime <-  as.POSIXct(df$sunsetTime, origin = "1970-01-01", tz = df$timezone)
   if ("time" %in% colnames(df))
-    df$time <-  as.POSIXct(df$time, origin = "1970-01-01", tz = df$timezone)  
+    df$time <-  as.POSIXct(df$time, origin = "1970-01-01", tz = df$timezone)
   df
 }
 
@@ -47,12 +47,12 @@ getWeatherForecast <- function(apiKey, lat = NA, lon = NA, city = NA, raw = FALS
       simpleError("You have to specify city or lat/lon")
     }
   }
-  
+
   forecastJson <- rjson::fromJSON(rawToChar(forecast$content), method = "C")
   if (raw) return(forecastJson)
-  
+
   now = addWeatherVariables(as.data.frame(forecastJson$currently))
-  if (class(forecastJson$hourly$data) == "list") {
+  if (inherits(forecastJson$hourly$data, "list")) {
     props <- c("time", "summary", "precipProbability", "temperature", "apparentTemperature", "dewPoint", "humidity", "windSpeed")
     tmp <- do.call(data.frame, lapply(props, function(p) {
       do.call(rbind, lapply(forecastJson$hourly$data, function(x) x[[p]] ))
@@ -62,7 +62,7 @@ getWeatherForecast <- function(apiKey, lat = NA, lon = NA, city = NA, raw = FALS
   } else {
     by.hour = addWeatherVariables(forecastJson$hourly$data)
   }
-  if (class(forecastJson$hourly$data) == "list") {
+  if (inherits(forecastJson$hourly$data, "list")) {
     props <- c("time", "summary", "sunriseTime", "sunsetTime", "temperatureMin", "temperatureMax",
                "apparentTemperatureMax", "apparentTemperatureMin",
                "temperatureMaxTime","temperatureMinTime",
@@ -75,7 +75,7 @@ getWeatherForecast <- function(apiKey, lat = NA, lon = NA, city = NA, raw = FALS
   } else {
     by.day= addWeatherDailyVariables(forecastJson$daily$data)
   }
-  
-  list(now = now, by.hour = by.hour, by.day = by.day)  
+
+  list(now = now, by.hour = by.hour, by.day = by.day)
 }
 
